import { Component, OnInit, ViewChild } from "@angular/core";
import { IgxSpreadsheetComponent } from "igniteui-angular-spreadsheet";
import { ExcelUtility } from "./ExcelUtility";

@Component({
  selector: "app-root",
  styleUrls: ["./app.component.scss"],
  templateUrl: "./app.component.html"
})
export class AppComponent implements OnInit {
  @ViewChild("spreadsheet", { read: IgxSpreadsheetComponent, static: true })
  public spreadsheet: IgxSpreadsheetComponent;

  public data: any[];

  constructor() { }

  public ngOnInit() {
      const excelFile = "https://static.infragistics.com/xplatform/excel/SalesData.xlsx"
      ExcelUtility.loadFromUrl(excelFile).then((w) => {
          this.spreadsheet.workbook = w;
      });


      this.data = [
        { Date: "Jan 1, 2019", Revenue: 16914, Expenses: 10183 },
        { Date: "Mar 1, 2019", Revenue: 15077, Expenses: 12813 },
        { Date: "Jun 1, 2019", Revenue: 16886, Expenses: 14476 },
        { Date: "Sep 1, 2019", Revenue: 17652, Expenses: 11705 },
        { Date: "Jan 1, 2020", Revenue: 21082, Expenses: 14044 },
        { Date: "Mar 1, 2020", Revenue: 17737, Expenses: 12803 },
        { Date: "Jun 1, 2020", Revenue: 18687, Expenses: 13677 },
        { Date: "Sep 1, 2020", Revenue: 21470, Expenses: 13717 },
        { Date: "Jan 1, 2021", Revenue: 28072, Expenses: 17133 }
    ];

    for(let i=0; i<this.data.length; i++){
        const item = this.data[i];

        item.Income = item.Revenue - item.Expenses;
        item.IncomePerRevenue = (item.Income / item.Revenue * 100);
    }

  }

  public openFile(input: HTMLInputElement): void {
      if (input.files == null || input.files.length === 0) {
      return;
      }

      // console.log("Files:" + input.files[0].name);

      ExcelUtility.load(input.files[0]).then((w) => {
      this.spreadsheet.workbook = w;
      }, (e) => {
          console.error("Workbook Load Error:" + e);
      });
  }

  public workbookSave(): void {
      ExcelUtility.save(
          this.spreadsheet.workbook, ".xlsx")
  }
}
